/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_STOCKS;

import fr.unistra.sil.erp.back.controller.IRetrieveStocks;
import fr.unistra.sil.erp.back.model.Stock;

import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import fr.unistra.sil.erp.back.repository.IStocksRepository;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Retrieves stocks in JSON format.
 *
 * @author BEAUVAIS ANTOINE
 */
@RestController
public class ApiRetrieveStocks implements IRetrieveStocks {

    /**
     * Stock repository.
    */
    private final IStocksRepository repository;

    /**
     *
     * @param repository
     */
    public ApiRetrieveStocks(IStocksRepository repository) {
        this.repository = repository;
    }

    /**
     * Sends the stocks as JSON format back to the client.
     *
     * @param request  the HTTP request.
     * @param response the HTTP response.
     * @return the response.
     * @throws ApiServerErrorException if the request could not be served.
     */
    @GetMapping(MAPPING_STOCKS)
    @Override
    public ResponseEntity<Object> retrieveStocks(HttpServletRequest request, HttpServletResponse response) throws ApiServerErrorException {
        List<Stock> res = repository.getStocks();
        if (res == null)
            throw new ApiServerErrorException("Database failure.");

        return new ResponseEntity<>(res, HttpStatus.OK);
    }
}
