package fr.unistra.sil.erp.back.controller.api;

import fr.unistra.sil.erp.back.model.Stock;
import fr.unistra.sil.erp.back.service.CantUpdateStockException;
import fr.unistra.sil.erp.back.service.UpdateStockRequest;
import fr.unistra.sil.erp.back.service.UpdateStockService;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_STOCKS;

/**
 *
 * @author antoine.beauvais
 */
@Controller
public class ApiUpdateStockController {
    private final UpdateStockService service;

    /**
     *
     * @param service
     */
    public ApiUpdateStockController(UpdateStockService service) {
        this.service = service;
    }

    /**
     * Creates a product.
     *
     * @param requestBody request body
     * @return a JSON response.
     * @throws ApiBadRequestException if the request could not be served.
     */
    @PutMapping(MAPPING_STOCKS)
    public ResponseEntity<Stock> putStock(
            @Validated @RequestBody PutStockDTO requestBody
    ) throws ApiBadRequestException {
        Stock stock;
        try {
            stock = service.update(new UpdateStockRequest(
                    requestBody.getItemId(),
                    requestBody.getQuantity()
            ));
        } catch (CantUpdateStockException e) {
            throw new ApiBadRequestException(e.getMessage());
        }

        return new ResponseEntity<>(stock, HttpStatus.CREATED);
    }
}
