/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

/**
 * Representation of a stock entry.
 * 
 * Stocks simply provide the available quantity for each item.
 * 
 * If an item's quantity is depleted, it cannot be sold.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class Stock {
    
    /**
     * The stock entry's ID.
     */
    private final int id;

    private final Item item;

    /**
     * The quantity for the item.
     */
    private int quantity;
    
    /**
     * Class constructor.
     * @param id the Stock's ID.
     * @param item the Stock's item
     * @param quantity the quantity.
     */
    public Stock(int id, Item item, int quantity)
    {
        this.id = id;
        this.item = item;
        this.quantity = quantity;
    }
    
    public Stock(Item item, int quantity)
    {
        this.id = 0;
        this.item = item;
        this.quantity = quantity;
    }
    
    /**
     * Returns the stock ID.
     * @return the stock's ID.
     */
    public int getId()
    {
        return this.id;
    }

    /**
     * Returns the item's ID.
     * @return the item's ID.
     */
    public Item getItem()
    {
        return this.item;
    }

    /**
     * Returns the quantity for the item.
     * @return the quantity.
     */
    public int getQuantity()
    {
        return this.quantity;
    }

    /**
     *
     * @param quantity
     */
    public void addQuantity(int quantity) {
        this.quantity += quantity;
        if (this.quantity < 0) {
            this.quantity = 0;
        }
    }
}
